@@ -2,10 +2,10 @@ from django.apps import AppConfig
 
 
 class ScheduleConfig(AppConfig):
-    name = 'pretalx.schedule'
+    name = "pretalx.schedule"
 
     def ready(self):
         from . import signals  # noqa
 
 
-default_app_config = 'pretalx.schedule.ScheduleConfig'
+default_app_config = "pretalx.schedule.ScheduleConfig"
